==> scilab_5.1.1.orig.tar.gz: scilab-5.1.1/modules/graphics/src/c/getHandleProperty/get_viewport_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_viewport_property.c                                          */
/* desc : function to retrieve in Scilab the viewport field of            */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_viewport_property( sciPointObj * pobj )
{
  int viewport[4] ;

  if( sciGetEntityType(pobj) != SCI_FIGURE )
  {
    Scierror(999, _("%s property does not exist for this handle.\n"), "viewport") ;
    return -1 ;
  }

  sciGetViewport( pobj, viewport ) ;

  /* For now we just give viewport position */
  /* until we have a better management of tab sizes */
  return sciReturnRowIntVector( viewport, 2 ) ;

}
/*------------------------------------------------------------------------*/

==> scilab_5.3.3.orig.tar.gz: scilab-5.3.3/modules/graphics/src/c/getHandleProperty/get_viewport_property.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007 - INRIA - Jean-Baptiste Silvy
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

/*------------------------------------------------------------------------*/
/* file: get_viewport_property.c                                          */
/* desc : function to retrieve in Scilab the viewport field of            */
/*        a handle                                                        */
/*------------------------------------------------------------------------*/

#include "getHandleProperty.h"
#include "GetProperty.h"
#include "returnProperty.h"
#include "Scierror.h"
#include "localization.h"

/*------------------------------------------------------------------------*/
int get_viewport_property( sciPointObj * pobj )
{
  int viewport[4] ;

  if( sciGetEntityType(pobj) != SCI_FIGURE )
  {
    Scierror(999, _("'%s' property does not exist for this handle.\n"), "viewport") ;
    return -1 ;
  }

  sciGetViewport( pobj, viewport ) ;

  /* For now we just give viewport position */
  /* until we have a better management of tab sizes */
  return sciReturnRowIntVector( viewport, 2 ) ;

}
/*------------------------------------------------------------------------*/
